==> org-lsst-ccs-ui-2.4.8-sources.jar: org/lsst/ccs/gconsole/agent/filter/Configuration.java <==
package org.lsst.ccs.gconsole.agent.filter;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import org.lsst.ccs.gconsole.agent.AgentChannelsFilter;
import org.lsst.ccs.gconsole.annotations.ConsoleLookup;

/**
 * Filter that selects subsystem state channels.
 *
 * @author onoprien
 */
@ConsoleLookup(id = "org.lsst.ccs.gconsole.agent.AgentChannelsFilter",
        name = "Configuration",
        path = "Built-In/Configuration",
        description = "Channels filter that selects subsystem configuration channels.<p>"
                + "<b>Optional parameters:</b>"
                + "<dl>"
                + "<dt>agents</dt><dd>Comma-separated list of subsystems accepted by this filter.</dd>"
                + "</dl>")
public class Configuration implements AgentChannelsFilter {

// -- Fields : -----------------------------------------------------------------
    
    private final List<String> agents;

// -- Life cycle : -------------------------------------------------------------
    
    public Configuration(String agents) {
        if (agents.trim().isEmpty()) {
            this.agents = null;
        } else if (agents.trim().equals("\"\"")) {
            this.agents = Collections.emptyList();
        } else {
            String[] ss = agents.split(",");
            this.agents = new ArrayList<>(ss.length);
            for (String s : ss) {
                this.agents.add(s.trim());
            }
        }
    }
    
// -- Implementing filter : ----------------------------------------------------

    @Override
    public List<String> getDisplayPath(String originPath) {
        String displayPath = originPath.replaceFirst("/configuration/", "/");
        return Collections.singletonList(displayPath);
    }

    @Override
    public String getOriginPath(String displayPath) {
        return displayPath.replaceFirst("/", "/configuration/");
    }

    @Override
    public List<String> getOriginChannels() {
        return Collections.singletonList("/configuration/");
    }

    @Override
    public List<String> getAgents() {
        return agents;
    }

    @Override
    public String getName() {
        return "Configuration";
    }

}

==> org-lsst-ccs-ui-2.4.11-sources.jar: org/lsst/ccs/gconsole/agent/filter/Configuration.java <==
package org.lsst.ccs.gconsole.agent.filter;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import org.lsst.ccs.gconsole.agent.AgentChannelsFilter;
import org.lsst.ccs.gconsole.annotations.ConsoleLookup;

/**
 * Filter that selects subsystem state channels.
 *
 * @author onoprien
 */
@ConsoleLookup(id = "org.lsst.ccs.gconsole.agent.AgentChannelsFilter",
        name = "Configuration",
        path = "Built-In/Configuration",
        description = "Channels filter that selects subsystem configuration channels.<p>"
                + "<b>Optional parameters:</b>"
                + "<dl>"
                + "<dt>agents</dt><dd>Comma-separated list of subsystems accepted by this filter.</dd>"
                + "</dl>")
public class Configuration extends AbstractChannelsFilter {

// -- Fields : -----------------------------------------------------------------
    
    private final List<String> agents;

// -- Life cycle : -------------------------------------------------------------
    
    public Configuration(String agents) {
        if (agents.trim().isEmpty()) {
            this.agents = null;
        } else if (agents.trim().equals("\"\"")) {
            this.agents = Collections.emptyList();
        } else {
            String[] ss = agents.split(",");
            this.agents = new ArrayList<>(ss.length);
            for (String s : ss) {
                this.agents.add(s.trim());
            }
        }
    }
    
// -- Implementing filter : ----------------------------------------------------

    @Override
    public List<String> getDisplayPath(String originPath) {
        String displayPath = originPath.replaceFirst("/configuration/", "/");
        return Collections.singletonList(displayPath);
    }

    @Override
    public String getOriginPath(String displayPath) {
        return displayPath.replaceFirst("/", "/configuration/");
    }

    @Override
    public List<String> getOriginChannels() {
        return Collections.singletonList("/configuration/");
    }

    @Override
    public List<String> getAgents() {
        return agents;
    }

    @Override
    public String getName() {
        return "Configuration";
    }

}
